@@ -2,7 +2,8 @@
 
 ### Default method.
 spmd.allgather.default <- function(x, x.buffer = NULL, x.count = NULL,
-    displs = NULL, comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    displs = NULL, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   all.array <- spmd.allreduce.integer(as.integer(is.array(x)),
                                       integer(1), op = "sum",
                                       comm = comm) == spmd.comm.size(comm)
@@ -18,19 +19,22 @@ spmd.allgatherv.default <- spmd.allgather.default
 
 ### For allgather and basic types.
 spmd.allgather.integer <- function(x, x.buffer, x.count = NULL,
-    displs = NULL, comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    displs = NULL, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   .Call("spmd_allgather_integer", x, x.buffer,
         as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.allgather.double().
 
 spmd.allgather.double <- function(x, x.buffer, x.count = NULL,
-    displs = NULL, comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    displs = NULL, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   .Call("spmd_allgather_double", x, x.buffer,
         as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.allgather.double().
 
 spmd.allgather.raw <- function(x, x.buffer, x.count = NULL,
-    displs = NULL, comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    displs = NULL, comm = .pbd_env$SPMD.CT$comm,
+    unlist = .pbd_env$SPMD.CT$unlist){
   .Call("spmd_allgather_raw", x, x.buffer,
         as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.allgather.raw().
@@ -39,21 +43,21 @@ spmd.allgather.raw <- function(x, x.buffer, x.count = NULL,
 ### For allgatherv and basic types.
 spmd.allgatherv.integer <- function(x, x.buffer, x.count,
     displs = c(0L, cumsum(x.count)),
-    comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    comm = .pbd_env$SPMD.CT$comm, unlist = .pbd_env$SPMD.CT$unlist){
   .Call("spmd_allgatherv_integer", x, x.buffer, x.count, displs,
         as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.allgatherv.integer().
 
 spmd.allgatherv.double <- function(x, x.buffer, x.count,
     displs = c(0L, cumsum(x.count)),
-    comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    comm = .pbd_env$SPMD.CT$comm, unlist = .pbd_env$SPMD.CT$unlist){
   .Call("spmd_allgatherv_double", x, x.buffer, x.count, displs,
         as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.allgatherv.double().
 
 spmd.allgatherv.raw <- function(x, x.buffer, x.count,
     displs = c(0L, cumsum(x.count)),
-    comm = .SPMD.CT$comm, unlist = .SPMD.CT$unlist){
+    comm = .pbd_env$SPMD.CT$comm, unlist = .pbd_env$SPMD.CT$unlist){
   .Call("spmd_allgatherv_raw", x, x.buffer, x.count, displs,
         as.integer(comm), PACKAGE = "pbdMPI")
 } # End of spmd.allgatherv.raw().
