@@ -1,7 +1,7 @@
 ### SHELL> mpiexec -np 4 Rscript divide.r
 
 ### Initial.
-library(pbdMPI, quietly = TRUE)
+suppressMessages(library(pbdMPI, quietly = TRUE))
 init()
 .comm.size <- comm.size()
 .comm.rank <- comm.rank()
@@ -23,5 +23,14 @@ comm.cat(">>> cycle (all)\n", quiet = TRUE)
 alljid <- get.jid(7, method = "cycle", all = TRUE)
 comm.print(alljid)
 
+comm.cat(">>> block (all, reduced)\n", quiet = TRUE)
+alljid.list <- get.jid(7, method = "block", all = TRUE, reduced = TRUE)
+comm.print(alljid.list)
+
+comm.cat(">>> cycle (all, reduced)\n", quiet = TRUE)
+alljid.list <- get.jid(7, method = "cycle", all = TRUE, reduced = TRUE)
+comm.print(alljid.list)
+
+
 ### Finish.
 finalize()
