@@ -45,6 +45,8 @@ rmpi_array_pointers MPI_APTS, *MPI_APTS_ptr;
 SEXP arrange_MPI_APTS();
 void set_MPI_APTS_in_R();
 void get_MPI_APTS_from_R();
+SEXP get_MPI_COMM_PTR();
+SEXP addr_MPI_COMM_PTR();
 
 /* In "pkg_dl.c". */
 extern void *DL_APT_ptr;
