@@ -41,6 +41,7 @@ SEXP spmd_barrier(SEXP R_comm);
 SEXP spmd_comm_is_null(SEXP R_comm);
 SEXP spmd_comm_size(SEXP R_comm);
 SEXP spmd_comm_rank(SEXP R_comm);
+SEXP spmd_comm_localrank(SEXP R_comm);
 SEXP spmd_comm_dup(SEXP R_comm, SEXP R_newcomm);
 SEXP spmd_comm_free(SEXP R_comm);
 SEXP spmd_comm_set_errhandler(SEXP R_comm);
@@ -165,12 +166,16 @@ SEXP spmd_allreduce_integer(SEXP R_send_data, SEXP R_recv_data,
 		SEXP R_op, SEXP R_comm);
 SEXP spmd_allreduce_double(SEXP R_send_data, SEXP R_recv_data,
 		SEXP R_op, SEXP R_comm);
+SEXP spmd_allreduce_float(SEXP R_send_data, SEXP R_recv_data,
+		SEXP R_op, SEXP R_comm);
 
 /* In file "spmd_reduce.c". */
 SEXP spmd_reduce_integer(SEXP R_send_data, SEXP R_recv_data,
 		SEXP R_op, SEXP R_rank_dest, SEXP R_comm);
 SEXP spmd_reduce_double(SEXP R_send_data, SEXP R_recv_data,
 		SEXP R_op, SEXP R_rank_dest, SEXP R_comm);
+SEXP spmd_reduce_float(SEXP R_send_data, SEXP R_recv_data,
+		SEXP R_op, SEXP R_rank_dest, SEXP R_comm);
 
 /* In file "spmd_bcast.c". */
 SEXP spmd_bcast_integer(SEXP R_send_data, SEXP R_rank_source, SEXP R_comm);
@@ -242,4 +247,3 @@ SEXP AsInt(int x);
 int spmd_errhandler(int error_code);
 
 #endif
-
